@@ -26,9 +26,7 @@ import (
 
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/pkg/appstore"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 )
 
 func init() {
@@ -40,15 +38,9 @@ var installCmd = &cobra.Command{
 	Use:           "install <CERT> <KEY> <PROFILE>",
 	Short:         "Install private key, certificate & provisioning profile for Xcode signing",
 	Args:          cobra.ExactArgs(3),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		if err := appstore.InstallCertificateAndKey(args[0], args[1]); err != nil {
 			log.Errorf("installing certificate and key: %w", err)
 		}
