@@ -39,7 +39,6 @@ import (
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/info"
 	"github.com/blacktop/ipsw/pkg/plist"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -72,7 +71,7 @@ func init() {
 	downloadWikiCmd.Flags().StringP("output", "o", "", "Folder to download files to")
 	downloadWikiCmd.MarkFlagDirname("output")
 	downloadWikiCmd.Flags().String("db", "wiki_db.json", "Path to local JSON database (will use CWD by default)")
-	downloadWikiCmd.Flags().BoolP("flat", "f", false, "Do NOT perserve directory structure when downloading with --pattern")
+	downloadWikiCmd.Flags().BoolP("flat", "f", false, "Do NOT preserve directory structure when downloading with --pattern")
 	// Bind persistent flags
 	viper.BindPFlag("download.wiki.proxy", downloadWikiCmd.Flags().Lookup("proxy"))
 	viper.BindPFlag("download.wiki.insecure", downloadWikiCmd.Flags().Lookup("insecure"))
@@ -120,11 +119,6 @@ var downloadWikiCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// settings
 		proxy := viper.GetString("download.wiki.proxy")
 		insecure := viper.GetBool("download.wiki.insecure")
