@@ -34,7 +34,6 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/download"
 	"github.com/blacktop/ipsw/internal/utils"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -57,6 +56,10 @@ func init() {
 	viper.BindPFlag("download.xcode.skip-all", downloadXcodeCmd.Flags().Lookup("skip-all"))
 	viper.BindPFlag("download.xcode.resume-all", downloadXcodeCmd.Flags().Lookup("resume-all"))
 	viper.BindPFlag("download.xcode.restart-all", downloadXcodeCmd.Flags().Lookup("restart-all"))
+	// Bind command-specific flags
+	viper.BindPFlag("download.xcode.latest", downloadXcodeCmd.Flags().Lookup("latest"))
+	viper.BindPFlag("download.xcode.sim", downloadXcodeCmd.Flags().Lookup("sim"))
+	viper.BindPFlag("download.xcode.runtime", downloadXcodeCmd.Flags().Lookup("runtime"))
 }
 
 // downloadXcodeCmd represents the xcode command
@@ -79,11 +82,6 @@ var downloadXcodeCmd = &cobra.Command{
 	Hidden: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// settings
 		proxy := viper.GetString("download.xcode.proxy")
 		insecure := viper.GetBool("download.xcode.insecure")
@@ -91,9 +89,9 @@ var downloadXcodeCmd = &cobra.Command{
 		resumeAll := viper.GetBool("download.xcode.resume-all")
 		restartAll := viper.GetBool("download.xcode.restart-all")
 		// flags
-		latest, _ := cmd.Flags().GetBool("latest")
-		dlSim, _ := cmd.Flags().GetBool("sim")
-		runtime, _ := cmd.Flags().GetString("runtime")
+		latest := viper.GetBool("download.xcode.latest")
+		dlSim := viper.GetBool("download.xcode.sim")
+		runtime := viper.GetString("download.xcode.runtime")
 
 		if dlSim {
 			dvt, err := download.GetDVTDownloadableIndex()
