@@ -51,6 +51,7 @@ func init() {
 	entCmd.Flags().String("pg-password", "", "PostgreSQL password")
 	entCmd.Flags().String("pg-database", "", "PostgreSQL database name")
 	entCmd.Flags().String("pg-sslmode", "require", "PostgreSQL SSL mode (disable, require, verify-ca, verify-full)")
+	entCmd.Flags().String("pg-poolmode", "", "PostgreSQL pool mode (session, transaction, statement, or empty for no pooling)")
 
 	// Search flags
 	entCmd.Flags().StringP("key", "k", "", "Search for entitlement key pattern")
@@ -63,6 +64,11 @@ func init() {
 	entCmd.Flags().Bool("stats", false, "Show database statistics")
 	entCmd.Flags().Int("limit", 100, "Limit number of results")
 
+	// Replacement flags
+	entCmd.Flags().Bool("replace", false, "Replace older builds of the same iOS version with newer builds")
+	entCmd.Flags().String("replace-strategy", "auto", "Replacement strategy: auto, prompt, force")
+	entCmd.Flags().Bool("dry-run", false, "Show what would be replaced without making changes")
+
 	// Viper bindings
 	viper.BindPFlag("ent.ipsw", entCmd.Flags().Lookup("ipsw"))
 	viper.BindPFlag("ent.input", entCmd.Flags().Lookup("input"))
@@ -73,6 +79,7 @@ func init() {
 	viper.BindPFlag("ent.pg-password", entCmd.Flags().Lookup("pg-password"))
 	viper.BindPFlag("ent.pg-database", entCmd.Flags().Lookup("pg-database"))
 	viper.BindPFlag("ent.pg-sslmode", entCmd.Flags().Lookup("pg-sslmode"))
+	viper.BindPFlag("ent.pg-poolmode", entCmd.Flags().Lookup("pg-poolmode"))
 	viper.BindPFlag("ent.key", entCmd.Flags().Lookup("key"))
 	viper.BindPFlag("ent.value", entCmd.Flags().Lookup("value"))
 	viper.BindPFlag("ent.file", entCmd.Flags().Lookup("file"))
@@ -80,6 +87,9 @@ func init() {
 	viper.BindPFlag("ent.file-only", entCmd.Flags().Lookup("file-only"))
 	viper.BindPFlag("ent.stats", entCmd.Flags().Lookup("stats"))
 	viper.BindPFlag("ent.limit", entCmd.Flags().Lookup("limit"))
+	viper.BindPFlag("ent.replace", entCmd.Flags().Lookup("replace"))
+	viper.BindPFlag("ent.replace-strategy", entCmd.Flags().Lookup("replace-strategy"))
+	viper.BindPFlag("ent.dry-run", entCmd.Flags().Lookup("dry-run"))
 
 }
 
@@ -113,7 +123,13 @@ var entCmd = &cobra.Command{
 		❯ ipsw ent --sqlite entitlements.db --stats
 
 		# Search PostgreSQL database (Supabase)
-		❯ ipsw ent --pg-host db.xyz.supabase.co --pg-user postgres --pg-password your-password --pg-database postgres --key sandbox`),
+		❯ ipsw ent --pg-host db.xyz.supabase.co --pg-user postgres --pg-password your-password --pg-database postgres --key sandbox
+		
+		# Replace older iOS builds with newer ones
+		❯ ipsw ent --sqlite entitlements.db --ipsw iPhone16,1_26.0_22G87_Restore.ipsw --replace
+		
+		# Preview what would be replaced
+		❯ ipsw ent --sqlite entitlements.db --ipsw iPhone16,1_26.0_22G87_Restore.ipsw --replace --dry-run`),
 	Args:          cobra.NoArgs,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
@@ -131,6 +147,7 @@ var entCmd = &cobra.Command{
 		pgPassword := viper.GetString("ent.pg-password")
 		pgDatabase := viper.GetString("ent.pg-database")
 		pgSSLMode := viper.GetString("ent.pg-sslmode")
+		pgPoolMode := viper.GetString("ent.pg-poolmode")
 		keyPattern := viper.GetString("ent.key")
 		valuePattern := viper.GetString("ent.value")
 		filePattern := viper.GetString("ent.file")
@@ -138,6 +155,9 @@ var entCmd = &cobra.Command{
 		fileOnly := viper.GetBool("ent.file-only")
 		showStats := viper.GetBool("ent.stats")
 		limit := viper.GetInt("ent.limit")
+		replace := viper.GetBool("ent.replace")
+		replaceStrategy := viper.GetString("ent.replace-strategy")
+		dryRun := viper.GetBool("ent.dry-run")
 
 		// Validate required flags
 		if sqliteDB == "" && pgHost == "" {
@@ -171,6 +191,19 @@ var entCmd = &cobra.Command{
 			return fmt.Errorf("--key, --value, --file, and --stats are mutually exclusive")
 		}
 
+		// Validate replacement flags
+		if replace && (keyPattern != "" || valuePattern != "" || filePattern != "" || showStats) {
+			return fmt.Errorf("--replace cannot be used with search operations")
+		}
+
+		if replaceStrategy != "auto" && replaceStrategy != "prompt" && replaceStrategy != "force" {
+			return fmt.Errorf("--replace-strategy must be one of: auto, prompt, force")
+		}
+
+		if dryRun && !replace {
+			return fmt.Errorf("--dry-run can only be used with --replace")
+		}
+
 		// Validate PostgreSQL flags if using PostgreSQL
 		if pgHost != "" {
 			if pgUser == "" || pgDatabase == "" {
@@ -190,7 +223,13 @@ var entCmd = &cobra.Command{
 		// Handle database creation
 		if len(ipsws) > 0 || len(inputs) > 0 {
 			if pgHost != "" {
-				return ent.CreatePostgreSQLDatabase(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode, ipsws, inputs)
+				if replace {
+					return ent.CreatePostgreSQLDatabaseWithReplacement(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode, pgPoolMode, ipsws, inputs, replaceStrategy, dryRun)
+				}
+				return ent.CreatePostgreSQLDatabase(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode, pgPoolMode, ipsws, inputs)
+			}
+			if replace {
+				return ent.CreateSQLiteDatabaseWithReplacement(sqliteDB, ipsws, inputs, replaceStrategy, dryRun)
 			}
 			return ent.CreateSQLiteDatabase(sqliteDB, ipsws, inputs)
 		}
@@ -199,14 +238,14 @@ var entCmd = &cobra.Command{
 
 		if showStats {
 			if pgHost != "" {
-				return ent.ShowPostgreSQLStatistics(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode)
+				return ent.ShowPostgreSQLStatistics(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode, pgPoolMode)
 			}
 			return ent.ShowSQLiteStatistics(sqliteDB)
 		}
 
 		// Perform search
 		if pgHost != "" {
-			return ent.SearchPostgreSQLEntitlements(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode, keyPattern, valuePattern, filePattern, versionFilter, fileOnly, limit)
+			return ent.SearchPostgreSQLEntitlements(pgHost, pgPort, pgUser, pgPassword, pgDatabase, pgSSLMode, pgPoolMode, keyPattern, valuePattern, filePattern, versionFilter, fileOnly, limit)
 		}
 		return ent.SearchSQLiteEntitlements(sqliteDB, keyPattern, valuePattern, filePattern, versionFilter, fileOnly, limit)
 	},
