@@ -22,7 +22,6 @@ THE SOFTWARE.
 package fw
 
 import (
-	"github.com/apex/log"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -47,10 +46,6 @@ var pmpCmd = &cobra.Command{
 	Hidden:  true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-
 		// flags
 		// output := viper.GetString("fw.pmp.output")
 
