@@ -30,7 +30,7 @@ import (
 // backupCreateCmd represents the create command
 var backupCreateCmd = &cobra.Command{
 	Use:   "create",
-	Short: "A brief description of your command",
+	Short: "Create a backup",
 	Long: `A longer description that spans multiple lines and likely contains examples
 and usage of using your command. For example:
 
