@@ -31,7 +31,6 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/commands/device"
 	"github.com/blacktop/ipsw/pkg/tss"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -75,15 +74,9 @@ func init() {
 var idevImgSignCmd = &cobra.Command{
 	Use:           "sign",
 	Short:         "Personalize DDI",
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		xcode := viper.GetString("idev.img.sign.xcode")
 		ddiDmgPath := viper.GetString("idev.img.sign.ddi-dmg")
