@@ -36,7 +36,6 @@ import (
 	"github.com/blacktop/ipsw/pkg/usb/lockdownd"
 	"github.com/blacktop/ipsw/pkg/usb/pcap"
 	"github.com/caarlos0/ctrlc"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -47,24 +46,20 @@ func init() {
 	PcapCmd.Flags().StringP("proc", "p", "", "process to get pcap for")
 	PcapCmd.Flags().StringP("output", "o", "", "Folder to save pcap")
 	PcapCmd.MarkFlagDirname("output")
+	viper.BindPFlag("idev.pcap.proc", PcapCmd.Flags().Lookup("proc"))
+	viper.BindPFlag("idev.pcap.output", PcapCmd.Flags().Lookup("output"))
 }
 
 // PcapCmd represents the pcap command
 var PcapCmd = &cobra.Command{
 	Use:           "pcap",
 	Short:         "Dump network traffic",
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
-		proc, _ := cmd.Flags().GetString("proc")
-		output, _ := cmd.Flags().GetString("output")
+		udid := viper.GetString("idev.udid")
+		proc := viper.GetString("idev.pcap.proc")
+		output := viper.GetString("idev.pcap.output")
 
 		var err error
 		var dev *lockdownd.DeviceValues
