@@ -30,7 +30,6 @@ import (
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/usb/lockdownd"
 	"github.com/blacktop/ipsw/pkg/usb/springboard"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -40,6 +39,7 @@ func init() {
 
 	idevSpringbIconCmd.Flags().StringP("output", "o", "", "Folder to save icon")
 	idevSpringbIconCmd.MarkFlagDirname("output")
+	viper.BindPFlag("idev.springb.icon.output", idevSpringbIconCmd.Flags().Lookup("output"))
 }
 
 // idevSpringbIconCmd represents the icon command
@@ -47,17 +47,11 @@ var idevSpringbIconCmd = &cobra.Command{
 	Use:           "icon",
 	Short:         "Dump application icon as PNG",
 	Args:          cobra.MinimumNArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
-		output, _ := cmd.Flags().GetString("output")
+		udid := viper.GetString("idev.udid")
+		output := viper.GetString("idev.springb.icon.output")
 
 		var err error
 		var dev *lockdownd.DeviceValues
