@@ -47,11 +47,13 @@ func init() {
 	mountCmd.Flags().String("pem-db", "", "AEA pem DB JSON file")
 	mountCmd.Flags().StringP("mount-point", "m", "", "Custom mount point (default: /tmp/<dmg>.mount)")
 	mountCmd.Flags().String("ident", "", "Identity Variant to select specific RestoreRamDisk (e.g. 'Erase', 'Upgrade', 'Recovery')")
+	mountCmd.Flags().BoolP("detach", "d", false, "Mount without blocking (leave mounted in background)")
 	viper.BindPFlag("mount.key", mountCmd.Flags().Lookup("key"))
 	viper.BindPFlag("mount.lookup", mountCmd.Flags().Lookup("lookup"))
 	viper.BindPFlag("mount.pem-db", mountCmd.Flags().Lookup("pem-db"))
 	viper.BindPFlag("mount.mount-point", mountCmd.Flags().Lookup("mount-point"))
 	viper.BindPFlag("mount.ident", mountCmd.Flags().Lookup("ident"))
+	viper.BindPFlag("mount.detach", mountCmd.Flags().Lookup("detach"))
 }
 
 // mountCmd represents the mount command
@@ -79,6 +81,9 @@ var mountCmd = &cobra.Command{
 
 		# Mount a RestoreRamDisk by identity (defaults to the first if not specified)
 		$ ipsw mount rdisk iPhone.ipsw --ident Erase
+
+		# Mount in background without blocking (detach mode)
+		$ ipsw mount fs iPhone.ipsw --detach
 	`),
 	ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
@@ -98,6 +103,7 @@ var mountCmd = &cobra.Command{
 		pemDB := viper.GetString("mount.pem-db")
 		mountPoint := viper.GetString("mount.mount-point")
 		ident := viper.GetString("mount.ident")
+		detach := viper.GetBool("mount.detach")
 		// validate flags
 		if len(key) > 0 && lookupKeys {
 			return fmt.Errorf("cannot use --key AND --lookup flags together")
@@ -157,13 +163,18 @@ var mountCmd = &cobra.Command{
 			log.Infof("Mounted %s DMG %s", args[0], filepath.Base(mctx.DmgPath))
 		}
 
-		// block until user hits ctrl-c
-		done := make(chan os.Signal, 1)
-		signal.Notify(done, syscall.SIGINT, syscall.SIGTERM)
-		utils.Indent(log.Info, 2)(fmt.Sprintf("Press Ctrl+C to unmount '%s' ...", mctx.MountPoint))
-		<-done
+		if detach {
+			utils.Indent(log.Info, 2)(fmt.Sprintf("Detaching, run `hdiutil detach %s` to unmount manually", mctx.MountPoint))
+			return nil
+		} else {
+			// block until user hits ctrl-c
+			done := make(chan os.Signal, 1)
+			signal.Notify(done, syscall.SIGINT, syscall.SIGTERM)
+			utils.Indent(log.Info, 2)(fmt.Sprintf("Press Ctrl+C to unmount '%s' ...", mctx.MountPoint))
+			<-done
 
-		utils.Indent(log.Info, 2)(fmt.Sprintf("Unmounting %s", mctx.MountPoint))
-		return mctx.Unmount()
+			utils.Indent(log.Info, 2)(fmt.Sprintf("Unmounting %s", mctx.MountPoint))
+			return mctx.Unmount()
+		}
 	},
 }
