@@ -90,7 +90,7 @@ var otaPayloadCmd = &cobra.Command{
 				}
 			}
 		} else {
-			o, err := ota.Open(filepath.Clean(args[0]), viper.GetString("ota.key-val"))
+			o, err := ota.Open(filepath.Clean(args[0]), ResolveAEAKeyFromFlags(args[0]))
 			if err != nil {
 				return fmt.Errorf("failed to open OTA file: %v", err)
 			}
