@@ -34,10 +34,7 @@ import (
 	"github.com/spf13/viper"
 )
 
-var (
-	userConfigDir string
-	cfgFile       string
-)
+var cfgFile string
 
 // rootCmd represents the base command when called without any subcommands
 var rootCmd = &cobra.Command{
