@@ -37,21 +37,24 @@ type AI interface {
 	// FIXME: dump convienence method to set models from cache
 	SetModels(map[string]string) (map[string]string, error)
 	SetModel(string) error
+	Verify() error
 	Close() error
 }
 
 type Config struct {
-	UUID         string
-	Provider     string
-	Prompt       string
-	Model        string
-	Temperature  float64
-	TopP         float64
-	Stream       bool
-	DisableCache bool
-	Verbose      bool
-	MaxRetries   int
-	RetryBackoff time.Duration
+	UUID           string
+	Provider       string
+	Prompt         string
+	Model          string
+	Temperature    float64
+	TopP           float64
+	TemperatureSet bool
+	TopPSet        bool
+	Stream         bool
+	DisableCache   bool
+	Verbose        bool
+	MaxRetries     int
+	RetryBackoff   time.Duration
 }
 
 type CachingAI struct {
@@ -173,6 +176,10 @@ func (c *CachingAI) SetModels(models map[string]string) (map[string]string, erro
 	return c.ai.SetModels(models)
 }
 
+func (c *CachingAI) Verify() error {
+	return c.ai.Verify()
+}
+
 func (c *CachingAI) Close() error {
 	var errs []error
 	if c.ai != nil {
@@ -217,11 +224,13 @@ func NewAI(ctx context.Context, cfg *Config) (AI, error) {
 	switch cfg.Provider {
 	case "claude":
 		baseAI, err = anthropic.NewClaude(ctx, &anthropic.Config{
-			Prompt:      cfg.Prompt,
-			Model:       cfg.Model,
-			Temperature: cfg.Temperature,
-			TopP:        cfg.TopP,
-			Stream:      cfg.Stream,
+			Prompt:         cfg.Prompt,
+			Model:          cfg.Model,
+			Temperature:    cfg.Temperature,
+			TemperatureSet: cfg.TemperatureSet,
+			TopP:           cfg.TopP,
+			TopPSet:        cfg.TopPSet,
+			Stream:         cfg.Stream,
 		})
 	case "copilot":
 		baseAI, err = copilot.NewCopilot(ctx, &copilot.Config{
