@@ -14,11 +14,11 @@ func (h _Heap) Swap(i, j int) {
 	h[i], h[j] = h[j], h[i]
 }
 
-func (h *_Heap) Push(x interface{}) {
+func (h *_Heap) Push(x any) {
 	*h = append(*h, x.(_Chunk))
 }
 
-func (h *_Heap) Pop() (x interface{}) {
+func (h *_Heap) Pop() (x any) {
 	last := len(*h) - 1
 	x = (*h)[last]
 	*h = (*h)[:last]
